export interface TreeItem {
  value: string;
  current: boolean;
  children: TreeItem[];
  weight: number;
  pretty: string | null;
}

export class TreeItemConstructor {
  value: string;
  current: boolean;
  children: TreeItemConstructor[] = [];
  weight: number;
  pretty: string | null;

  constructor(
    value = "root",
    current = false,
    pretty: string | null = null,
    weight = 0
  ) {
    this.value = value;
    this.current = current;
    this.pretty = pretty;
    this.weight = weight;
  }

  addChild(child: TreeItemConstructor) {
    this.children.push(child);
  }

  plain(): TreeItem {
    return {
      value: this.value,
      current: this.current,
      children: this.children.map((child) => child.plain()),
      weight: this.weight,
      pretty: this.pretty,
    };
  }

  sort() {
    this.children.forEach((child) => child.sort());
    this.children.sort((a, b) => b.weight - a.weight);

    return this;
  }
}

export const findCurrentDir = (node: TreeItem): TreeItem | null => {
  if (!node.current) {
    return null;
  }

  const further = node.children.find(
    (child) => child.current && child.children.length !== 0
  );

  if (further) {
    return further;
  }

  return findCurrentDir(node);
};
